#loggedUsers {
	border:1px solid #8CACBB;
	width: 20%; 
	height: 20em;
	float: right;
	overflow: auto;
	padding: 0;
}

#loggedUsers div {
	background: url(user.gif) no-repeat 2px;
	padding: 0;
	padding-left: 18px;
	margin: 0.5em;
	font-weight: bold;
}

#messages {
	border:1px solid #8CACBB;
  	width: 75%;
	height: 20em;
	padding:0;
	float: left;
	overflow: auto;
	background-color: #f3f3f3;
}

.msg_time  {	
	color: gray;
}

.msg_user  {	
	margin-left: 0.5em;
	margin-right: 0.5em;
	color: red;
	font-weight: bold;
}

.msgBox {
	margin-top: 1em;
	float: left;
	clear: left;
	width: 90%;
}
.msgBox input {
	width: 75%;	
}


